import React from 'react';
import {
  View,
  TouchableOpacity,
  Dimensions,
  Modal,
  Platform,
  Image,
} from 'react-native';

import Button from './button';
import { BlurView } from '@react-native-community/blur';
import Text from './text';

const { width: SCREEN_WIDTH, height: SCREEN_HEIGHT } = Dimensions.get('window');

interface CommonModalProps {
  isVisible: boolean;
  mainTitle: string;
  subTitle: string;
  onClose: () => void;
  onConfirm?: () => void; // 선택적으로 만들어 버튼 한 개일 때도 사용 가능
}

const CommonModal = ({
  isVisible,
  mainTitle,
  subTitle,
  onClose,
  onConfirm,
}: CommonModalProps) => {
  return (
    <View>
      <Modal visible={isVisible} transparent animationType="fade">
        <TouchableOpacity
          activeOpacity={1}
          onPress={onClose}
          style={{
            width: SCREEN_WIDTH,
            height: SCREEN_HEIGHT,
          }}
        >
          {Platform.OS === 'android' ? (
            <BlurView
              style={{
                position: 'absolute',
                top: 0,
                left: 0,
                bottom: 0,
                right: 0,
              }}
              blurType="dark"
              blurAmount={10}
            />
          ) : (
            <Image
              style={{
                position: 'absolute',
                top: 0,
                left: 0,
                bottom: 0,
                right: 0,
              }}
              resizeMode="cover"
              source={require('./images/blurImg.png')}
              blurRadius={10}
            />
          )}
          <View className="w-full h-full justify-center items-center">
            <View className="w-[80%] rounded-2xl p-[20px] bg-white">
              <View className="items-start gap-[4px] pt-4 pb-[12px]">
                <Text
                  face={'title'}
                  weight={'bold'}
                  size={'small'}
                  textColor={'gray-900'}
                >
                  {mainTitle}
                </Text>
                <Text
                  face={'body'}
                  weight={'regular'}
                  size={'medium'}
                  textColor={'gray-700'}
                  className={'w-[78%]'}
                >
                  {subTitle}
                </Text>
              </View>

              <View
                className={`flex-row gap-2 ${!onConfirm ? 'justify-center' : ''}`}
              >
                {onConfirm ? (
                  // 버튼이 2개일 때
                  <>
                    <Button
                      text="취소"
                      variant="primaryLow"
                      className="flex-1"
                      onPress={onClose}
                    />
                    <Button
                      text="확인"
                      variant="primary"
                      className="flex-1"
                      onPress={onConfirm}
                    />
                  </>
                ) : (
                  // 버튼이 1개일 때
                  <Button
                    text="확인"
                    variant="danger"
                    shape="round"
                    className="flex-1"
                    onPress={onClose}
                  />
                )}
              </View>
            </View>
          </View>
        </TouchableOpacity>
      </Modal>
    </View>
  );
};

export default CommonModal;
